# coding: utf-8

"""
    Pulp 3 API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_rpm
from pulpcore.client.pulp_rpm.models.variant import Variant  # noqa: E501
from pulpcore.client.pulp_rpm.rest import ApiException

class TestVariant(unittest.TestCase):
    """Variant unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Variant
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_rpm.models.variant.Variant()  # noqa: E501
        if include_optional :
            return Variant(
                variant_id = '0', 
                uid = '0', 
                name = '0', 
                type = '0', 
                packages = '0', 
                source_packages = '0', 
                source_repository = '0', 
                debug_packages = '0', 
                debug_repository = '0', 
                identity = '0'
            )
        else :
            return Variant(
                variant_id = '0',
                uid = '0',
                name = '0',
                type = '0',
                packages = '0',
                source_packages = '0',
                source_repository = '0',
                debug_packages = '0',
                debug_repository = '0',
                identity = '0',
        )

    def testVariant(self):
        """Test Variant"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
